Learn R Programming

adea (version 1.5.1)

summary.adeaparametric: Summary method for adeaparametric class

Description

For the final model of adea_parametric function print the model name, orientation, load orientation, a summary, the input variables, and outputs variables.

Usage

# S3 method for adeaparametric
summary(object, ...)

Arguments

object

is the object of class adeaparametric to summarise

...

For compatibility reason, see note about `eff.tolerance` parameter.

Details

The default tolerance to consider a DMU as efficient one is .001 in reports. Use `eff.tolerance` parameter to consider another tolerance between 0 and 1.