For the final model of adea_parametric function print the model name, orientation, load orientation, a summary, the input variables, and outputs variables.
# S3 method for adeaparametric
summary(object, ...)is the object of class adeaparametric to summarise
For compatibility reason, see note about `eff.tolerance` parameter.
The default tolerance to consider a DMU as efficient one is .001 in reports. Use `eff.tolerance` parameter to consider another tolerance between 0 and 1.